@@ -1,11 +1,8 @@
-import os
 import sys
 
-dir_path = os.path.dirname(os.path.realpath(__file__))
-with open(os.path.join(dir_path, "version"), "r", encoding="utf-8") as version_file:
-    __version__ = version_file.read().strip()
+__version__ = "4.28.0"
 
-python_version = f"{sys.version_info[0]}.{sys.version_info[1]}"
+PYTHON_VERSION = f"{sys.version_info[0]}.{sys.version_info[1]}"
 
 
 def get_platform() -> str:
@@ -15,7 +12,8 @@ def get_platform() -> str:
         "win32": "windows",
         "darwin": "macos",
         "aix": "aix",
-        "freebsd": "freebsd",
+        "freebsd": "bsd",
+        "openbsd": "bsd",
     }
     for name, agent_name in platforms.items():
         if sys.platform.startswith(name):
