@@ -1,9 +1,10 @@
 """Test to check if style packages are in same versions as pre-commit config."""
 
-import configparser
 import re
 from pathlib import Path
 
+import toml
+
 
 def _test_version(versions_a, versions_b, key):
     assert versions_a[key].replace("v", "") == versions_b[key].replace("v", "")
@@ -11,11 +12,10 @@ def _test_version(versions_a, versions_b, key):
 
 def test_style_pkg_versions():
     """Check black, flake8, isort and pydocstyle versions consistency."""
-    config = configparser.ConfigParser()
-    config.read(Path(__file__).parent.parent.joinpath("setup.cfg"))
-    line_sep = re.compile(r"(==|~=)")
+    config = toml.load(Path(__file__).parent.parent.joinpath("pyproject.toml"))
+    line_sep = re.compile(r"(==|~=|>=)")
     requirements_versions = {}
-    for line in config["options.extras_require"]["dev"].split():
+    for line in config["project"]["optional-dependencies"]["lint"]:
         split_line = line_sep.split(line.strip())
         requirements_versions[split_line[0]] = split_line[2]
 
@@ -30,5 +30,5 @@ def test_style_pkg_versions():
                 pkg_version = lines[idx + 1].strip().split(":")[-1].strip()
                 pre_commit_versions[pkg_name] = pkg_version
 
-    for req in ("black", "pylint", "isort", "pydocstyle", "mypy"):
+    for req in ("pylint",):
         _test_version(requirements_versions, pre_commit_versions, req)
